"""Model definitions for CANNs.

This namespace exposes common model families, such as basic CANNs and
brain-inspired variants.

Examples:
    >>> from canns import models
    >>> print(models.basic)
"""

from . import basic as basic
from . import brain_inspired as brain_inspired
# from .hybrid import *
