"""CANNs pipeline entrypoints."""

from .asa import ASAApp
from .asa import main as asa_main
from .gallery import GalleryApp
from .gallery import main as gallery_main
from .launcher import main as launcher_main

try:
    from .asa_gui import ASAGuiApp
except Exception:  # PySide6 may be missing
    ASAGuiApp = None  # type: ignore

__all__ = [
    "ASAApp",
    "asa_main",
    "GalleryApp",
    "gallery_main",
    "launcher_main",
    "ASAGuiApp",
]
